==> huaweicloudsdkdrs-3.0.47-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/speed_limit_info.py <==
# coding: utf-8

import pprint
import re

import six





class SpeedLimitInfo:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'begin': 'str',
        'end': 'str',
        'speed': 'str'
    }

    attribute_map = {
        'begin': 'begin',
        'end': 'end',
        'speed': 'speed'
    }

    def __init__(self, begin=None, end=None, speed=None):
        """SpeedLimitInfo - a model defined in huaweicloud sdk"""
        
        

        self._begin = None
        self._end = None
        self._speed = None
        self.discriminator = None

        self.begin = begin
        self.end = end
        self.speed = speed

    @property
    def begin(self):
        """Gets the begin of this SpeedLimitInfo.

        开始限速时间, 此时间为UTC时间，开始时间为整时，若有分钟，则会忽略，格式为hh:mm，小时数为两位，例如：01:00。

        :return: The begin of this SpeedLimitInfo.
        :rtype: str
        """
        return self._begin

    @begin.setter
    def begin(self, begin):
        """Sets the begin of this SpeedLimitInfo.

        开始限速时间, 此时间为UTC时间，开始时间为整时，若有分钟，则会忽略，格式为hh:mm，小时数为两位，例如：01:00。

        :param begin: The begin of this SpeedLimitInfo.
        :type: str
        """
        self._begin = begin

    @property
    def end(self):
        """Gets the end of this SpeedLimitInfo.

        结束时间,此时间为UTC时间,输入必须为59分结尾，格式为hh:mm，小时数为两位，例如：05:59。

        :return: The end of this SpeedLimitInfo.
        :rtype: str
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this SpeedLimitInfo.

        结束时间,此时间为UTC时间,输入必须为59分结尾，格式为hh:mm，小时数为两位，例如：05:59。

        :param end: The end of this SpeedLimitInfo.
        :type: str
        """
        self._end = end

    @property
    def speed(self):
        """Gets the speed of this SpeedLimitInfo.

        限速，取值范围为1~9999 ,单位为MB/s

        :return: The speed of this SpeedLimitInfo.
        :rtype: str
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this SpeedLimitInfo.

        限速，取值范围为1~9999 ,单位为MB/s

        :param speed: The speed of this SpeedLimitInfo.
        :type: str
        """
        self._speed = speed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpeedLimitInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/speed_limit_info.py <==
# coding: utf-8

import re
import six





class SpeedLimitInfo:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'begin': 'str',
        'end': 'str',
        'speed': 'str'
    }

    attribute_map = {
        'begin': 'begin',
        'end': 'end',
        'speed': 'speed'
    }

    def __init__(self, begin=None, end=None, speed=None):
        """SpeedLimitInfo - a model defined in huaweicloud sdk"""
        
        

        self._begin = None
        self._end = None
        self._speed = None
        self.discriminator = None

        self.begin = begin
        self.end = end
        self.speed = speed

    @property
    def begin(self):
        """Gets the begin of this SpeedLimitInfo.

        开始限速时间, 此时间为UTC时间，开始时间为整时，若有分钟，则会忽略，格式为hh:mm，小时数为两位，例如：01:00。

        :return: The begin of this SpeedLimitInfo.
        :rtype: str
        """
        return self._begin

    @begin.setter
    def begin(self, begin):
        """Sets the begin of this SpeedLimitInfo.

        开始限速时间, 此时间为UTC时间，开始时间为整时，若有分钟，则会忽略，格式为hh:mm，小时数为两位，例如：01:00。

        :param begin: The begin of this SpeedLimitInfo.
        :type: str
        """
        self._begin = begin

    @property
    def end(self):
        """Gets the end of this SpeedLimitInfo.

        结束时间,此时间为UTC时间,输入必须为59分结尾，格式为hh:mm，小时数为两位，例如：05:59。

        :return: The end of this SpeedLimitInfo.
        :rtype: str
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this SpeedLimitInfo.

        结束时间,此时间为UTC时间,输入必须为59分结尾，格式为hh:mm，小时数为两位，例如：05:59。

        :param end: The end of this SpeedLimitInfo.
        :type: str
        """
        self._end = end

    @property
    def speed(self):
        """Gets the speed of this SpeedLimitInfo.

        限速，取值范围为1~9999 ,单位为MB/s

        :return: The speed of this SpeedLimitInfo.
        :rtype: str
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this SpeedLimitInfo.

        限速，取值范围为1~9999 ,单位为MB/s

        :param speed: The speed of this SpeedLimitInfo.
        :type: str
        """
        self._speed = speed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpeedLimitInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
